[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/r0x0d/oogg/main.svg)](https://results.pre-commit.ci/latest/github/r0x0d/oogg/main)
[![Tests](https://github.com/r0x0d/oogg/actions/workflows/tests.yml/badge.svg)](https://github.com/r0x0d/oogg/actions/workflows/tests.yml)

# OOGG

This tools aim to be a helper to open files at the GitHub or GitLab page without
going and try to search it in their UI.

I made this because I was switching throught a lot of files daily and sometimes
I wanted to see them on GitHub because of the jump to code feature.

This tool is mostly useless.
